from django.apps import AppConfig


class GitHubAuthConfig(AppConfig):
    name = "django_rest_github_oauth"
